@@ -7,16 +7,18 @@ __email__ = "talley.lambert@gmail.com"
 
 from ._dynamic_plugin import DynamicPlugin
 from ._plugin_manager import PluginContext, PluginManager
-from .io_utils import read, write
-from .manifest import PluginManifest
-from .manifest.package_metadata import PackageMetadata
+from .io_utils import read, read_get_reader, write, write_get_writer
+from .manifest import PackageMetadata, PluginManifest
 
 __all__ = [
+    "DynamicPlugin",
     "PluginManifest",
     "PluginManager",
     "PluginContext",
     "PackageMetadata",
-    "DynamicPlugin",
     "write",
     "read",
+    "read_get_reader",
+    "write",
+    "write_get_writer",
 ]
